



cmake --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake -V -P SSLTest.cmake
IF %ERRORLEVEL% NEQ 0 exit /B 1
ctest --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
cpack --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
